@@ -54,7 +54,8 @@ class admin_indexFrameContainer extends BaseFrameContainer
 			return true;
 		} else if($cmd == M3_REQUEST_CMD_SHOW_WIDGET ||		// ウィジェットの単体表示
 					$cmd == M3_REQUEST_CMD_DO_WIDGET ||		// ウィジェット単体実行
-					$cmd == M3_REQUEST_CMD_CONFIG_WIDGET){	// ウィジェットの設定
+					$cmd == M3_REQUEST_CMD_CONFIG_WIDGET ||	// ウィジェットの設定
+					$cmd == M3_REQUEST_CMD_SHOW_PHPINFO){	// phpinfoの表示
 			// 管理者権限がなければ実行できない
 			if ($gEnvManager->isSystemAdmin()){
 				return true;
