@@ -1711,18 +1711,22 @@ class SystemDb extends BaseDb
 	 * コンテンツのビューカウント総数を取得
 	 *
 	 * @param string    $typeId				コンテンツタイプ
-	 * @param int     	$serial				シリアル番号
+	 * @param array,int $serial				シリアル番号
 	 * @param timestamp	$startDt			期間(開始日)
 	 * @param timestamp	$endDt				期間(終了日)
 	 * @return int							総数
 	 */
 	function getTotalViewCount($typeId, $serial, $startDt = null, $endDt = null)
 	{
+		$count = 0;
 		$params = array();
 		$queryStr  = 'SELECT SUM(vc_count) AS total FROM _view_count ';
 		$queryStr .=   'WHERE vc_type_id = ? ';	$params[] = $typeId;		// データタイプはデフォルトコンテンツ
-		$queryStr .=     'AND vc_content_serial = ? '; $params[] = $serial;
-
+		if (is_array($serial)){	// 配列のとき
+			$queryStr .=	'AND vc_content_serial in (' . implode(",", $serial) . ') ';
+		} else {
+			$queryStr .=	'AND vc_content_serial = ? '; $params[] = $serial;
+		}
 		// 日付範囲
 		if (!empty($startDt)){
 			$queryStr .=    'AND ? <= vc_date ';
@@ -1732,7 +1736,6 @@ class SystemDb extends BaseDb
 			$queryStr .=    'AND vc_date < ? ';
 			$params[] = $endDt;
 		}
-		$count = 0;
 		$ret = $this->selectRecord($queryStr, $params, $row);
 		if ($ret) $count = intval($row['total']);
 		return $count;
