@@ -236,14 +236,11 @@ CREATE TABLE product_category (
 DROP TABLE IF EXISTS product_with_category;
 CREATE TABLE product_with_category (
     pw_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
-    pw_product_id        INT            DEFAULT 0                     NOT NULL,      -- 商品ID
-    pw_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
-    pw_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
+    pw_product_serial    INT            DEFAULT 0                     NOT NULL,      -- 商品シリアル番号
     pw_index             INT            DEFAULT 0                     NOT NULL,      -- インデックス番号
     pw_category_id       INT            DEFAULT 0                     NOT NULL,      -- 商品カテゴリーID
-    pw_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
     PRIMARY KEY          (pw_serial),
-    UNIQUE               (pw_product_id,        pw_language_id,       pw_history_index,     pw_index)
+    UNIQUE               (pw_product_serial,    pw_index)
 ) TYPE=innodb;
 
 -- 価格種別マスター
