@@ -141,7 +141,7 @@ CREATE TABLE blog_config (
     PRIMARY KEY          (bg_id)
 ) TYPE=innodb;
 INSERT INTO blog_config (bg_id,              bg_value,    bg_name,                     bg_index)
-VALUES                 ('receive_comment',   '0',         'コメントを受け付け',        1);
+VALUES                 ('receive_comment',   '0',         'コメントの受け付け',        1);
 INSERT INTO blog_config (bg_id,              bg_value,    bg_name,                     bg_index)
 VALUES                 ('receive_trackback', '0',         'トラックバックの受け付け',  2);
 INSERT INTO blog_config (bg_id,              bg_value,    bg_name,                     bg_index)
@@ -205,14 +205,11 @@ CREATE TABLE blog_entry (
 DROP TABLE IF EXISTS blog_entry_with_category;
 CREATE TABLE blog_entry_with_category (
     bw_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
-    bw_entry_id          INT            DEFAULT 0                     NOT NULL,      -- ブログ記事ID
-    bw_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
-    bw_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
+    bw_entry_serial      INT            DEFAULT 0                     NOT NULL,      -- ブログ記事シリアル番号
     bw_index             INT            DEFAULT 0                     NOT NULL,      -- インデックス番号
     bw_category_id       INT            DEFAULT 0                     NOT NULL,      -- ブログ記事カテゴリーID
-    bw_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
     PRIMARY KEY          (bw_serial),
-    UNIQUE               (bw_entry_id,        bw_language_id,       bw_history_index,     bw_index)
+    UNIQUE               (bw_entry_serial,      bw_index)
 ) TYPE=innodb;
 
 -- ブログコメントトラン
@@ -220,14 +217,16 @@ DROP TABLE IF EXISTS blog_comment;
 CREATE TABLE blog_comment (
     bo_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
     bo_entry_id          INT            DEFAULT 0                     NOT NULL,      -- エントリーID
+    bo_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
     bo_user_id           INT            DEFAULT 0                     NOT NULL,      -- ユーザID
     bo_regist_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 投稿日時
     
-    bo_title             VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- タイトル
+    bo_name              VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- タイトル
     bo_html              VARCHAR(200)   DEFAULT ''                    NOT NULL,      -- 本文HTML
     bo_url               TEXT           DEFAULT ''                    NOT NULL,      -- 参照用URL
     bo_user_name         VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- ユーザ名
     bo_email             VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- Eメールアドレス
+    bo_status            SMALLINT       DEFAULT 0                     NOT NULL,      -- 状態(0=未設定、1=非公開、2=公開)
     
     bo_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
     bo_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
