@@ -178,6 +178,17 @@ class _installCheckenvWidgetContainer extends BaseWidgetContainer
 		}
 		$this->tmpl->addVar("_widget","current_access", $data);
 		
+		// ##### セッション関係 #####
+		// セッション起動
+		$data = '<b><font color="green">off</font></b>';
+		$this->tmpl->addVar("_widget","config_sess_auto_start", $data);
+		if (ini_get('session.auto_start')){
+			$data = '<b><font color="red">on</font></b>';
+		} else {
+			$data = '<b><font color="green">off</font></b>';
+		}
+		$this->tmpl->addVar("_widget","current_sess_auto_start", $data);
+		
 		// セッション保存用パス
 		$sp = ini_get('session.save_path');
 		$this->tmpl->addVar("_widget","current_session_path", $sp);
