@@ -76,7 +76,7 @@ class admin_mainTopWidgetContainer extends BaseWidgetContainer
 				// サブレベル取得
 				$this->db->getNavItems('admin_menu', $topId, $subRows);
 				// 初期表示画面
-				if (count($subRows) > 0) $firstTask = '?task=' . $subRows[0]['ni_task_id'];
+				if (count($subRows) > 0) $firstTask = $gEnvManager->getDefaultAdminUrl() . '?task=' . $subRows[0]['ni_task_id'];
 				
 				// 「li」タグ
 				$menuInner .= '<li class="toppage-menu">';
@@ -85,7 +85,7 @@ class admin_mainTopWidgetContainer extends BaseWidgetContainer
 				// リンク先を作成。「_」で始まるタスクはリンクを作成しない
 				$topLink = '#';
 				$linkTask = $rows[$i]['ni_task_id'];
-				if (strncmp($linkTask, '_', strlen('_')) != 0) $topLink = '?task=' . $linkTask;	// 起動タスクパラメータを設定
+				if (strncmp($linkTask, '_', strlen('_')) != 0) $topLink = $gEnvManager->getDefaultAdminUrl() . '?task=' . $linkTask;	// 起動タスクパラメータを設定
 				
 				// ヘルプの作成
 				$helpText = '';
@@ -116,7 +116,7 @@ class admin_mainTopWidgetContainer extends BaseWidgetContainer
 						$menuInner .= str_repeat(' ', 8);
 						$menuInner .= '<li ';
 						$menuInner .= '><a href="';
-						$menuInner .= '?task=' . $subRows[$l]['ni_task_id'];	// 起動タスクパラメータを設定
+						$menuInner .= $gEnvManager->getDefaultAdminUrl() . '?task=' . $subRows[$l]['ni_task_id'];	// 起動タスクパラメータを設定
 						if (!empty($subRows[$l]['ni_param'])){		// パラメータが存在するときはパラメータを追加
 							$menuInner .= '&' . M3_REQUEST_PARAM_OPERATION_TODO . '=' . urlencode($subRows[$l]['ni_param']);
 						}
