@@ -51,6 +51,10 @@ class admin_blog_mainBaseWidgetContainer extends BaseWidgetContainer
 			case 'entry_detail':	// ブログ記事詳細
 				$linkList = ' &gt;&gt; ブログ記事 &gt;&gt; 記事一覧';// パンくずリスト
 				break;
+			case 'comment':		// ブログ記事コメント
+			case 'comment_detail':	// ブログ記事コメント
+				$linkList = ' &gt;&gt; ブログ記事 &gt;&gt; コメント一覧';// パンくずリスト
+				break;
 			case 'user':		// ユーザ管理
 			case 'user_detail':		// ユーザ管理(詳細)
 				$linkList = ' &gt;&gt; ユーザ管理 &gt;&gt; ユーザ一覧';// パンくずリスト
@@ -108,13 +112,22 @@ class admin_blog_mainBaseWidgetContainer extends BaseWidgetContainer
 		$menuText .= '<div id="configmenu-lower">' . M3_NL;
 		$menuText .= '<ul>' . M3_NL;
 
-		if ($task == 'entry' ||
-			$task == 'entry_detail'){	// ブログ記事管理
+		if ($task == 'entry' ||		// ブログ記事管理
+			$task == 'entry_detail' ||
+			$task == 'comment' ||		// ブログ記事コメント管理
+			$task == 'comment_detail'){
+			
 			// ブログ記事一覧
 			$current = '';
 			$link = $baseUrl . '&task=entry';
-			if ($task == 'entry') $current = 'id="current"';
+			if ($task == 'entry' || $task == 'entry_detail') $current = 'id="current"';
 			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>記事一覧</span></a></li>' . M3_NL;
+			
+			// ブログ記事コメント一覧
+			$current = '';
+			$link = $baseUrl . '&task=comment';
+			if ($task == 'comment' || $task == 'comment_detail') $current = 'id="current"';
+			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>コメント一覧</span></a></li>' . M3_NL;
 /*		} else if ($task == 'user' ||
 			$task == 'user_detail'){	// ユーザ管理
 			// ユーザ一覧
