@@ -21,7 +21,9 @@ class admin_blog_mainConfigWidgetContainer extends admin_blog_mainBaseWidgetCont
 	private $db;	// DB接続オブジェクト
 	const RECEIVE_COMMENT		= 'receive_comment';		// コメントを受け付けるかどうか
 	const RECEIVE_TRACKBACK		= 'receive_trackback';		// トラックバックを受け付けるかどうか
-			
+	const ENTRY_VIEW_COUNT		= 'entry_view_count';			// 記事表示数
+	const ENTRY_VIEW_ORDER		= 'entry_view_order';			// 記事表示方向
+	
 	/**
 	 * コンストラクタ
 	 */
@@ -63,29 +65,51 @@ class admin_blog_mainConfigWidgetContainer extends admin_blog_mainBaseWidgetCont
 		$defaultLang	= $gEnvManager->getDefaultLanguage();
 		
 		$act = $request->trimValueOf('act');
-		
+		$entryViewCount = $request->trimValueOf('entry_view_count');		// 記事表示数
+		$entryViewOrder = $request->trimValueOf('entry_view_order');		// 記事表示順
 		$receiveComment = ($request->trimValueOf('receive_comment') == 'on') ? 1 : 0;		// コメントを受け付けるかどうか
 		
 		if ($act == 'update'){		// 設定更新のとき
 			// 入力値のエラーチェック
+			$this->checkNumeric($entryViewCount, '記事表示順');
 			
 			if ($this->getMsgCount() == 0){			// エラーのないとき
 				$isErr = false;
 				
 				if (!$isErr){
-					if (!$this->db->updateConfig(self::RECEIVE_COMMENT, $receiveComment)) $isErr = true;
+					if (!$this->db->updateConfig(self::ENTRY_VIEW_COUNT, $entryViewCount)) $isErr = true;// 記事表示数
+				}
+				if (!$isErr){
+					if (!$this->db->updateConfig(self::ENTRY_VIEW_ORDER, $entryViewOrder)) $isErr = true;// 記事表示順
+				}
+				if (!$isErr){
+					if (!$this->db->updateConfig(self::RECEIVE_COMMENT, $receiveComment)) $isErr = true;// コメントを受け付けるかどうか
+				}
+				if ($isErr){
+					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
+				} else {
+					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
 				}
-			
 				// 値を再取得
+				$entryViewCount	= $this->db->getConfig(self::ENTRY_VIEW_COUNT);// 記事表示数
+				$entryViewOrder	= $this->db->getConfig(self::ENTRY_VIEW_ORDER);// 記事表示順
 				$receiveComment	= $this->db->getConfig(self::RECEIVE_COMMENT);
 			}
 		} else {		// 初期表示の場合
+			$entryViewCount	= $this->db->getConfig(self::ENTRY_VIEW_COUNT);// 記事表示数
+			$entryViewOrder	= $this->db->getConfig(self::ENTRY_VIEW_ORDER);// 記事表示順
 			$receiveComment	= $this->db->getConfig(self::RECEIVE_COMMENT);
 		}
 		// 画面に書き戻す
+		$this->tmpl->addVar("_widget", "view_count", $entryViewCount);// 記事表示数
+		if (empty($entryViewOrder)){	// 順方向
+			$this->tmpl->addVar("_widget", "view_order_inc_selected", 'selected');// 記事表示順
+		} else {
+			$this->tmpl->addVar("_widget", "view_order_dec_selected", 'selected');// 記事表示順
+		}
 		$checked = '';
 		if ($receiveComment) $checked = 'checked';
-		$this->tmpl->addVar("_widget", "receive_comment", $checked);
+		$this->tmpl->addVar("_widget", "receive_comment", $checked);// コメントを受け付けるかどうか
 	}
 }
 ?>
