@@ -54,6 +54,11 @@ class admin_blog_mainWidgetContainer extends admin_blog_mainBaseWidgetContainer
 				$task = 'entry';
 				$goWidget = true;		// サブウィジェットを実行するかどうか
 				break;
+			case 'comment':		// ブログ記事コメント管理
+			case 'comment_detail':		// ブログ記事コメント管理(詳細)
+				$task = 'comment';
+				$goWidget = true;		// サブウィジェットを実行するかどうか
+				break;
 			case 'user':		// ユーザ管理
 			case 'user_detail':		// ユーザ管理(詳細)
 				$task = 'user';
