@@ -77,7 +77,7 @@ class blog_mainDb extends BaseDb
 			$queryStr .=  'WHERE be_language_id = ? '; $params[] = $langId;
 			$queryStr .=    'AND be_deleted = false ';		// 削除されていない
 		} else {
-			$queryStr = 'SELECT distinct(be_serial) FROM blog_entry RIGHT JOIN blog_entry_with_category ON be_id = bw_entry_id AND be_language_id = bw_language_id AND be_history_index = bw_history_index ';
+			$queryStr = 'SELECT distinct(be_serial) FROM blog_entry RIGHT JOIN blog_entry_with_category ON be_serial = bw_entry_serial ';
 			$queryStr .=  'WHERE be_language_id = ? '; $params[] = $langId;
 			$queryStr .=    'AND be_deleted = false ';		// 削除されていない
 			
@@ -145,7 +145,7 @@ class blog_mainDb extends BaseDb
 			$queryStr .=  'WHERE be_language_id = ? '; $params[] = $langId;
 			$queryStr .=    'AND be_deleted = false ';		// 削除されていない
 		} else {
-			$queryStr = 'SELECT distinct(be_serial) FROM blog_entry RIGHT JOIN blog_entry_with_category ON be_id = bw_entry_id AND be_language_id = bw_language_id AND be_history_index = bw_history_index ';
+			$queryStr = 'SELECT distinct(be_serial) FROM blog_entry RIGHT JOIN blog_entry_with_category ON be_serial = bw_entry_serial ';
 			$queryStr .=  'WHERE be_language_id = ? '; $params[] = $langId;
 			$queryStr .=    'AND be_deleted = false ';		// 削除されていない
 			
@@ -218,7 +218,14 @@ class blog_mainDb extends BaseDb
 			$keyword = addslashes($keyword);
 			
 			$queryStr .=    'AND (be_name LIKE \'%' . $keyword . '%\' ';
-			$queryStr .=    'OR be_html LIKE \'%' . $keyword . '%\') ';
+			$queryStr .=    'OR be_html LIKE \'%' . $keyword . '%\' ';
+			$queryStr .=    'OR be_html_ext LIKE \'%' . $keyword . '%\' ';
+			$queryStr .=    'OR be_description LIKE \'%' . $keyword . '%\') ';
+			/*
+			// 「'"\」文字をエスケープ
+			$keyword = addslashes($keyword);
+			$queryStr .=    'AND (be_name LIKE \'%' . $keyword . '%\' ';
+			$queryStr .=    'OR be_html LIKE \'%' . $keyword . '%\') ';*/
 		}
 		
 		$queryStr .=  'ORDER BY be_regist_dt desc limit ' . $limit . ' offset ' . $offset;
@@ -284,27 +291,20 @@ class blog_mainDb extends BaseDb
 		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
 		$this->execStatement($queryStr, array($entryId, $langId, $historyIndex, $name, $html, $status, $regUserId, $regDt, $userId, $now));
 		
+		// 新規のシリアル番号取得
+		$newSerial = 0;
+		$queryStr = 'select max(be_serial) as ns from blog_entry ';
+		$ret = $this->selectRecord($queryStr, array(), $row);
+		if ($ret) $newSerial = $row['ns'];
+		
 		// 記事カテゴリーの更新
-		if (count($category) == 0){		// 新規追加カテゴリーがないときは前レコードを削除
-			$ret = $this->updateEntryCategory($entryId, $langId, $historyIndex, -1, 0);
+		for ($i = 0; $i < count($category); $i++){
+			$ret = $this->updateEntryCategory($newSerial, $i, $category[$i]);
 			if (!$ret){
 				$this->endTransaction();
 				return false;
 			}
-		} else {
-			for ($i = 0; $i < count($category); $i++){
-				$ret = $this->updateEntryCategory($entryId, $langId, $historyIndex, $i, $category[$i]);
-				if (!$ret){
-					$this->endTransaction();
-					return false;
-				}
-			}
 		}
-		
-		// 新規のシリアル番号取得
-		$queryStr = 'select max(be_serial) as ns from blog_entry ';
-		$ret = $this->selectRecord($queryStr, array(), $row);
-		if ($ret) $newSerial = $row['ns'];
 			
 		// トランザクション確定
 		$ret = $this->endTransaction();
@@ -377,28 +377,21 @@ class blog_mainDb extends BaseDb
 		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
 		$this->execStatement($queryStr, array($entryId, $langId, $historyIndex, $name, $html, $status, $rUserId, $rDt, $userId, $now));
 
+		// 新規のシリアル番号取得
+		$newSerial = 0;
+		$queryStr = 'select max(be_serial) as ns from blog_entry ';
+		$ret = $this->selectRecord($queryStr, array(), $row);
+		if ($ret) $newSerial = $row['ns'];
+		
 		// 記事カテゴリーの更新
-		if (count($category) == 0){		// 新規追加カテゴリーがないときは前レコードを削除
-			$ret = $this->updateEntryCategory($entryId, $langId, $historyIndex, -1, 0);
+		for ($i = 0; $i < count($category); $i++){
+			$ret = $this->updateEntryCategory($newSerial, $i, $category[$i]);
 			if (!$ret){
 				$this->endTransaction();
 				return false;
 			}
-		} else {
-			for ($i = 0; $i < count($category); $i++){
-				$ret = $this->updateEntryCategory($entryId, $langId, $historyIndex, $i, $category[$i]);
-				if (!$ret){
-					$this->endTransaction();
-					return false;
-				}
-			}
 		}
 		
-		// 新規のシリアル番号取得
-		$queryStr = 'select max(be_serial) as ns from blog_entry ';
-		$ret = $this->selectRecord($queryStr, array(), $row);
-		if ($ret) $newSerial = $row['ns'];
-		
 		// トランザクション確定
 		$ret = $this->endTransaction();
 		return $ret;
@@ -406,51 +399,22 @@ class blog_mainDb extends BaseDb
 	/**
 	 * 記事カテゴリーの更新
 	 *
-	 * @param int        $entryId		記事ID
-	 * @param string     $langId		言語ID
-	 * @param string     $historyIndex	商品情報の履歴番号
-	 * @param int        $index			インデックス番号(-1のときはデータの追加なし)
+	 * @param int        $serial		記事シリアル番号
+	 * @param int        $index			インデックス番号
 	 * @param int        $categoryId	カテゴリーID
 	 * @return bool		 true = 成功、false = 失敗
 	 */
-	function updateEntryCategory($entryId, $langId, $historyIndex, $index, $categoryId)
+	function updateEntryCategory($serial, $index, $categoryId)
 	{
-		// １つ前のレコードを削除
-		if ($historyIndex > 0){		// 履歴番号
-			$queryStr  = 'SELECT * FROM blog_entry_with_category ';
-			$queryStr .=   'WHERE bw_entry_id = ? ';
-			$queryStr .=     'AND bw_language_id = ? ';
-			$queryStr .=     'AND bw_history_index = ? ';
-			$queryStr .=  'ORDER BY bw_index';
-			$ret = $this->selectRecord($queryStr, array($entryId, $langId, $historyIndex -1), $row);
-			if ($ret){
-				// レコードが削除されていない場合は削除
-				if (!$row['bw_deleted']){
-					// 古いレコードを削除
-					$queryStr  = 'UPDATE blog_entry_with_category ';
-					$queryStr .=   'SET bw_deleted = true ';	// 削除
-					$queryStr .=   'WHERE bw_entry_id = ? ';
-					$queryStr .=     'AND bw_language_id = ? ';
-					$queryStr .=     'AND bw_history_index = ? ';
-					$ret = $this->execStatement($queryStr, array($entryId, $langId, $historyIndex -1));
-					if (!$ret) return false;
-				}
-			}
-		}
-		// 新規レコード追加なしのときは終了
-		if ($index == -1) return true;
-		
 		// 新規レコード追加
 		$queryStr = 'INSERT INTO blog_entry_with_category ';
 		$queryStr .=  '(';
-		$queryStr .=  'bw_entry_id, ';
-		$queryStr .=  'bw_language_id, ';
-		$queryStr .=  'bw_history_index, ';
+		$queryStr .=  'bw_entry_serial, ';
 		$queryStr .=  'bw_index, ';
 		$queryStr .=  'bw_category_id) ';
 		$queryStr .=  'VALUES ';
-		$queryStr .=  '(?, ?, ?, ?, ?)';
-		$ret =$this->execStatement($queryStr, array($entryId, $langId, $historyIndex, $index, $categoryId));
+		$queryStr .=  '(?, ?, ?)';
+		$ret =$this->execStatement($queryStr, array($serial, $index, $categoryId));
 		return $ret;
 	}
 	/**
@@ -471,11 +435,9 @@ class blog_mainDb extends BaseDb
 		if ($ret){
 			// ブログカテゴリー
 			$queryStr  = 'SELECT * FROM blog_entry_with_category LEFT JOIN blog_category ON bw_category_id = bc_id AND bc_deleted = false ';
-			$queryStr .=   'WHERE bw_entry_id = ? ';
-			$queryStr .=     'AND bw_language_id = ? ';
-			$queryStr .=     'AND bw_history_index = ? ';// 履歴IDは共通
+			$queryStr .=   'WHERE bw_entry_serial = ? ';
 			$queryStr .=  'ORDER BY bw_index ';
-			$this->selectRecords($queryStr, array($row['be_id'], $row['be_language_id'], $row['be_history_index']), $categoryRow);
+			$this->selectRecords($queryStr, array($serial), $categoryRow);
 		}
 		return $ret;
 	}
@@ -530,15 +492,6 @@ class blog_mainDb extends BaseDb
 				$queryStr .=     'be_update_dt = ? ';
 				$queryStr .=   'WHERE be_serial = ?';
 				$this->execStatement($queryStr, array($userId, $now, $serial[$i]));
-		
-				// 記事カテゴリーを削除
-				$queryStr  = 'UPDATE blog_entry_with_category ';
-				$queryStr .=   'SET bw_deleted = true ';	// 削除
-				$queryStr .=   'WHERE bw_deleted = false ';
-				$queryStr .=     'AND bw_entry_id = ? ';
-				$queryStr .=     'AND bw_language_id = ? ';
-				$queryStr .=     'AND bw_history_index = ? ';
-				$this->execStatement($queryStr, array($row['be_id'], $row['be_language_id'], $row['be_history_index']));
 			} else {// 指定のシリアルNoのレコードが削除状態のときはエラー
 				$this->endTransaction();
 				return false;
@@ -604,10 +557,11 @@ class blog_mainDb extends BaseDb
 	 * @param timestamp	$endDt				期間(終了日)
 	 * @param int 		$itemCount			取得項目数(0のときは該当すべて)
 	 * @param string	$langId				言語
+	 * @param int		$order				取得順(0=昇順,1=降順)
 	 * @param function	$callback			コールバック関数
 	 * @return 			なし
 	 */
-	function getEntryItems($entryId, $startDt, $endDt, $itemCount, $langId, $callback)
+	function getEntryItems($entryId, $startDt, $endDt, $itemCount, $langId, $order, $callback)
 	{
 		// エントリーIDの指定がない場合は、期間で取得
 		if (empty($entryId)){
@@ -625,7 +579,9 @@ class blog_mainDb extends BaseDb
 				$queryStr .=    'AND be_regist_dt < ? ';
 				$params[] = $endDt;
 			}
-			$queryStr .=  'ORDER BY be_regist_dt DESC LIMIT ' . $itemCount;		// 投稿順
+			$ord = '';
+			if (!empty($order)) $ord = 'DESC ';
+			$queryStr .=  'ORDER BY be_regist_dt ' . $ord . 'LIMIT ' . $itemCount;		// 投稿順
 			$this->selectLoop($queryStr, $params, $callback, null);
 		} else {
 			$queryStr = 'SELECT * FROM blog_entry ';
