@@ -26,6 +26,7 @@ class admin_blogparts_boxWidgetContainer extends BaseWidgetContainer
 	private $paramObj;		// パラメータ保存用オブジェクト
 	const CONTENT_TYPE = 'blogparts';			// コンテンツタイプ
 	const DEFAULT_NAME_HEAD = '名称未設定';			// デフォルトの設定名
+	const DEFAULT_CONTENT = '<object classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=9,0,0,0" width="168" height="300" id="500musicbooth002" align="middle"><param name="allowScriptAccess" value="always" /><param name="movie" value="http://www.fiat-auto.co.jp/blogparts/500musicbooth/500musicbooth002.swf" /><param name="quality" value="high" /><param name="wmode" value="transparent"><param name="bgcolor" value="#ffffff" /><embed src="http://www.fiat-auto.co.jp/blogparts/500musicbooth/500musicbooth002.swf" quality="high" bgcolor="#ffffff" width="168" height="300" name="500musicbooth002" align="middle" wmode="transparent" allowScriptAccess="always" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></object>';
 	
 	/**
 	 * コンストラクタ
@@ -208,7 +209,7 @@ class admin_blogparts_boxWidgetContainer extends BaseWidgetContainer
 		if (empty($this->configId)){		// 新規登録の場合
 			$this->tmpl->setAttribute('item_name_visible', 'visibility', 'visible');// 名前入力フィールド表示
 			$name = $this->createDefaultName();			// デフォルト登録項目名
-			$html = '';
+			$html = self::DEFAULT_CONTENT;			// デフォルトのブログパーツを設定
 			$showTitle = 1;					// タイトルを表示するかどうか
 			$this->serialNo = 0;
 		} else {
