@@ -528,11 +528,14 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		$delibDt = '';
 		if ($fetchedRow['or_deliv_dt'] != $gEnvManager->getInitValueOfTimestamp()) $delibDt = $this->convertToDispDateTime($fetchedRow['or_deliv_dt']);
 		
+		// 会員ID
+		$memberId = intval($fetchedRow['or_custm_id']);
+		if ($memberId < 0) $memberId = $memberId * (-1);
 		$row = array(
 			'line_color' => $lineColor,											// 行のカラー
 			'index' => $index,													// 行番号
 			'serial' => $this->convertToDispString($fetchedRow['or_serial']),	// シリアル番号
-			'id' => $fetchedRow['or_custm_id'],			// 顧客ID
+			'id' => $memberId,			// 会員ID
 			'order_no' => $this->convertToDispString($fetchedRow['or_order_no']),		// 受注番号
 			'name' => $this->convertToDispString($fetchedRow['or_custm_name']),		// 顧客名
 			'total' => $dispPrice,		// 購入額
