@@ -223,7 +223,8 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 				$visible = $row['pt_visible'];	// 表示状態
 				$this->unitTypeId = $row['pt_unit_type_id'];	// 単位
 				$unitQuantity = $row['pt_unit_quantity'];		// 数量
-				$stockCount	= $row['pt_view_stock_count'];		// 表示在庫数
+				$stockCount	= $row['pe_stock_count'];		// 表示在庫数
+				if (empty($stockCount)) $stockCount = 0;
 				$description = $row['pt_description'];			// 説明
 				$description_short = $row['pt_description_short'];		// 簡易説明
 				$keyword = $row['pt_search_keyword'];					// 検索キーワード
@@ -273,7 +274,8 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 				$visible = $row['pt_visible'];	// 表示状態
 				$this->unitTypeId = $row['pt_unit_type_id'];	// 単位
 				$unitQuantity = $row['pt_unit_quantity'];		// 数量
-				$stockCount	= $row['pt_view_stock_count'];		// 表示在庫数
+				$stockCount	= $row['pe_stock_count'];		// 表示在庫数
+				if (empty($stockCount)) $stockCount = 0;
 				$description = $row['pt_description'];			// 説明
 				$description_short = $row['pt_description_short'];		// 簡易説明
 				$keyword = $row['pt_search_keyword'];					// 検索キーワード
@@ -387,7 +389,8 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 						$visible = $row['pt_visible'];	// 表示状態
 						$this->unitTypeId = $row['pt_unit_type_id'];	// 単位
 						$unitQuantity = $row['pt_unit_quantity'];		// 数量
-						$stockCount	= $row['pt_view_stock_count'];		// 表示在庫数
+						$stockCount	= $row['pe_stock_count'];		// 表示在庫数
+						if (empty($stockCount)) $stockCount = 0;
 						$description = $row['pt_description'];			// 説明
 						$description_short = $row['pt_description_short'];		// 簡易説明
 						$keyword = $row['pt_search_keyword'];					// 検索キーワード
@@ -472,7 +475,8 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 						$visible = $row['pt_visible'];	// 表示状態
 						$this->unitTypeId = $row['pt_unit_type_id'];	// 単位
 						$unitQuantity = $row['pt_unit_quantity'];		// 数量
-						$stockCount	= $row['pt_view_stock_count'];		// 表示在庫数
+						$stockCount	= $row['pe_stock_count'];		// 表示在庫数
+						if (empty($stockCount)) $stockCount = 0;
 						$description = $row['pt_description'];			// 説明
 						$description_short = $row['pt_description_short'];		// 簡易説明
 						$keyword = $row['pt_search_keyword'];					// 検索キーワード
@@ -586,7 +590,8 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 				$visible = $row['pt_visible'];	// 表示状態
 				$this->unitTypeId = $row['pt_unit_type_id'];	// 単位
 				$unitQuantity = $row['pt_unit_quantity'];		// 数量
-				$stockCount	= $row['pt_view_stock_count'];		// 表示在庫数
+				$stockCount	= $row['pe_stock_count'];		// 表示在庫数
+				if (empty($stockCount)) $stockCount = 0;
 				$description = $row['pt_description'];			// 説明
 				$description_short = $row['pt_description_short'];		// 簡易説明
 				$keyword = $row['pt_search_keyword'];					// 検索キーワード
