@@ -16,11 +16,13 @@
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath()	. '/ec_mainOrderDb.php');
 require_once($gEnvManager->getCurrentWidgetDbPath()	. '/ec_mainCartDb.php');
+require_once($gEnvManager->getCurrentWidgetDbPath() .	'/productDb.php');
 
 class ec_mainDeliveryWidgetContainer extends BaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
 	private $cartDb;		// カートアクセス用ＤＢオブジェクト
+	private $productDb;	// DB接続オブジェクト
 	private $state;	// 都道府県
 	private $deliveryMethod;		// 配送方法
 	private $cartId;
@@ -44,6 +46,7 @@ class ec_mainDeliveryWidgetContainer extends BaseWidgetContainer
 		// DB接続オブジェクト作成
 		$this->db = new ec_mainOrderDb();
 		$this->cartDb = new ec_mainCartDb();
+		$this->productDb = new productDb();
 		
 		// 価格計算用オブジェクト取得
 		$this->ecObj = $gInstanceManager->getObject(self::PRICE_OBJ_ID);
@@ -330,7 +333,7 @@ class ec_mainDeliveryWidgetContainer extends BaseWidgetContainer
 		$id = $fetchedRow['si_product_id'];	// 商品ID
 		
 		// 商品を取得
-		$ret = $this->cartDb->getProductByProductId($id, $this->langId, $row, $row2, $row3, $row4, $row5);
+		$ret = $this->productDb->getProductByProductId($id, $this->langId, $row, $row2, $row3, $row4, $row5);
 		if ($ret){
 			$name = $this->convertToDispString($row['pt_name']);		// 名前
 			$code = $this->convertToDispString($row['pt_code']);		// 商品コード
