@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -17,6 +17,67 @@ require_once($gEnvManager->getDbPath() . '/baseDb.php');
 
 class ec_mainPayMethodDb extends BaseDb
 {
+	/**
+	 * シリアル番号から支払方法IDを取得
+	 *
+	 * @param int		$serial				シリアル番号
+	 * @return string						支払方法ID。該当なしのときは空文字列
+	 */
+	function getPayMethodDefIdBySerial($serial)
+	{
+		$id = '';
+		$queryStr = 'SELECT * FROM pay_method_def ';
+		$queryStr .=  'WHERE po_deleted = false ';
+		$queryStr .=  'AND po_serial = ? ';
+		$ret = $this->selectRecord($queryStr, array($serial), $row);
+		if ($ret) $id = $row['po_id'];
+		return $id;
+	}
+	/**
+	 * 支払方法をシリアル番号で削除
+	 *
+	 * @param array   $serial		シリアルNo
+	 * @return						true=成功、false=失敗
+	 */
+	function deletePayMethodDefBySerial($serial)
+	{
+		global $gEnvManager;
+		
+		// 引数のエラーチェック
+		if (!is_array($serial)) return false;
+		if (count($serial) <= 0) return true;
+		
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$userId = $gEnvManager->getCurrentUserId();	// 現在のユーザ
+		
+		// トランザクション開始
+		$this->startTransaction();
+		
+		// 指定のシリアルNoのレコードが削除状態でないかチェック
+		for ($i = 0; $i < count($serial); $i++){
+			$queryStr  = 'SELECT * FROM pay_method_def ';
+			$queryStr .=   'WHERE po_deleted = false ';		// 未削除
+			$queryStr .=     'AND po_serial = ? ';
+			$ret = $this->isRecordExists($queryStr, array($serial[$i]));
+			// 存在しない場合は、既に削除されたとして終了
+			if (!$ret){
+				$this->endTransaction();
+				return false;
+			}
+		}
+		
+		// レコードを削除
+		$queryStr  = 'UPDATE pay_method_def ';
+		$queryStr .=   'SET po_deleted = true, ';	// 削除
+		$queryStr .=     'po_update_user_id = ?, ';
+		$queryStr .=     'po_update_dt = ? ';
+		$queryStr .=   'WHERE po_serial in (' . implode($serial, ',') . ') ';
+		$this->execStatement($queryStr, array($userId, $now));
+		
+		// トランザクション確定
+		$ret = $this->endTransaction();
+		return $ret;
+	}
 	/**
 	 * 支払い方法を取得
 	 *
