@@ -209,11 +209,9 @@ class productDb extends BaseDb
 			
 			// 商品カテゴリー
 			$queryStr  = 'SELECT * FROM product_with_category ';
-			$queryStr .=   'WHERE pw_product_id = ? ';
-			$queryStr .=     'AND pw_language_id = ? ';
-			$queryStr .=     'AND pw_history_index = ? ';// 履歴IDは共通
+			$queryStr .=   'WHERE pw_product_serial = ? ';
 			$queryStr .=  'ORDER BY pw_index ';
-			$this->selectRecords($queryStr, array($row['pt_id'], $row['pt_language_id'], $row['pt_history_index']), $row5);
+			$this->selectRecords($queryStr, array($row['pt_serial']), $row5);
 		}
 		return $ret;
 	}
@@ -261,11 +259,9 @@ class productDb extends BaseDb
 			
 			// 商品カテゴリー
 			$queryStr  = 'SELECT * FROM product_with_category ';
-			$queryStr .=   'WHERE pw_product_id = ? ';
-			$queryStr .=     'AND pw_language_id = ? ';
-			$queryStr .=     'AND pw_history_index = ? ';// 履歴IDは共通
+			$queryStr .=   'WHERE pw_product_serial = ? ';
 			$queryStr .=  'ORDER BY pw_index ';
-			$this->selectRecords($queryStr, array($row['pt_id'], $row['pt_language_id'], $row['pt_history_index']), $row5);
+			$this->selectRecords($queryStr, array($row['pt_serial']), $row5);
 		}
 		return $ret;
 	}
@@ -311,11 +307,9 @@ class productDb extends BaseDb
 			
 			// 商品カテゴリー
 			$queryStr  = 'SELECT * FROM product_with_category ';
-			$queryStr .=   'WHERE pw_product_id = ? ';
-			$queryStr .=     'AND pw_language_id = ? ';
-			$queryStr .=     'AND pw_history_index = ? ';// 履歴IDは共通
+			$queryStr .=   'WHERE pw_product_serial = ? ';
 			$queryStr .=  'ORDER BY pw_index ';
-			$this->selectRecords($queryStr, array($row['pt_id'], $row['pt_language_id'], $row['pt_history_index']), $row5);
+			$this->selectRecords($queryStr, array($row['pt_serial']), $row5);
 		}
 		return $ret;
 	}
@@ -352,6 +346,7 @@ class productDb extends BaseDb
 								$prices, $images, $statuses, $categories, $userId, &$newSerial)
 	{
 		$now = date("Y/m/d H:i:s");	// 現在日時
+		$newSerial = 0;
 		$startTran = false;			// この関数でトランザクションを開始したかどうか
 						
 		// トランザクション開始
@@ -450,7 +445,7 @@ class productDb extends BaseDb
 		}
 		// 商品カテゴリーの更新
 		for ($i = 0; $i < count($categories); $i++){
-			$ret = $this->updateProductCategory($pId, $lang, $historyIndex, $i, $categories[$i]);
+			$ret = $this->updateProductCategory($newSerial, $i, $categories[$i]);
 			if (!$ret){
 				if ($startTran) $this->endTransaction();
 				return false;
@@ -492,6 +487,7 @@ class productDb extends BaseDb
 	{
 		$startTran = false;			// この関数でトランザクションを開始したかどうか
 		$now = date("Y/m/d H:i:s");	// 現在日時
+		$newSerial = 0;
 				
 		// トランザクション開始
 		if (!$this->isInTransaction()){
@@ -595,7 +591,7 @@ class productDb extends BaseDb
 		}
 		// 商品カテゴリーの更新
 		for ($i = 0; $i < count($categories); $i++){
-			$ret = $this->updateProductCategory($pId, $lang, $historyIndex, $i, $categories[$i]);
+			$ret = $this->updateProductCategory($newSerial, $i, $categories[$i]);
 			if (!$ret){
 				if ($startTran) $this->endTransaction();
 				return false;
@@ -669,15 +665,6 @@ class productDb extends BaseDb
 		$queryStr .=     'AND ps_language_id = ? ';
 		$this->execStatement($queryStr, array($userId, $now, $row['pt_id'], $row['pt_language_id']));
 		
-		// 商品カテゴリーを削除
-		$queryStr  = 'UPDATE product_with_category ';
-		$queryStr .=   'SET pw_deleted = true ';	// 削除
-		$queryStr .=   'WHERE pw_deleted = false ';
-		$queryStr .=     'AND pw_product_id = ? ';
-		$queryStr .=     'AND pw_language_id = ? ';
-		$queryStr .=     'AND pw_history_index = ? ';
-		$this->execStatement($queryStr, array($row['pt_id'], $row['pt_language_id'], $row['pt_history_index']));
-		
 		// トランザクション確定
 		$ret = $this->endTransaction();
 		return $ret;
@@ -742,15 +729,6 @@ class productDb extends BaseDb
 		$queryStr .=     'AND ps_id = ? ';
 		$this->execStatement($queryStr, array($userId, $now, $row['pt_id']));
 		
-		// 商品カテゴリーを削除
-		$queryStr  = 'UPDATE product_with_category ';
-		$queryStr .=   'SET pw_deleted = true ';	// 削除
-		$queryStr .=   'WHERE pw_deleted = false ';
-		$queryStr .=     'AND pw_product_id = ? ';
-		$queryStr .=     'AND pw_language_id = ? ';
-		$queryStr .=     'AND pw_history_index = ? ';
-		$this->execStatement($queryStr, array($row['pt_id'], $row['pt_language_id'], $row['pt_history_index']));
-		
 		// トランザクション確定
 		$ret = $this->endTransaction();
 		return $ret;
@@ -1013,48 +991,22 @@ class productDb extends BaseDb
 	/**
 	 * 商品カテゴリーの更新
 	 *
-	 * @param int        $productId		商品ID
-	 * @param string     $langId		言語ID
-	 * @param string     $historyIndex	商品情報の履歴番号
+	 * @param int        $productSerial		商品シリアル番号
 	 * @param int        $index			インデックス番号
 	 * @param int        $categoryId	カテゴリーID
 	 * @return bool		 true = 成功、false = 失敗
 	 */
-	function updateProductCategory($productId, $langId, $historyIndex, $index, $categoryId)
+	function updateProductCategory($productSerial, $index, $categoryId)
 	{
-		// １つ前のレコードを削除
-		if ($historyIndex > 0){		// 履歴番号
-			$queryStr  = 'SELECT * FROM product_with_category ';
-			$queryStr .=   'WHERE pw_product_id = ? ';
-			$queryStr .=     'AND pw_language_id = ? ';
-			$queryStr .=     'AND pw_history_index = ? ';
-			$queryStr .=  'ORDER BY pw_index';
-			$ret = $this->selectRecord($queryStr, array($productId, $langId, $historyIndex -1), $row);
-			if ($ret){
-				// レコードが削除されていない場合は削除
-				if (!$row['pw_deleted']){
-					// 古いレコードを削除
-					$queryStr  = 'UPDATE product_with_category ';
-					$queryStr .=   'SET pw_deleted = true ';	// 削除
-					$queryStr .=   'WHERE pw_product_id = ? ';
-					$queryStr .=     'AND pw_language_id = ? ';
-					$queryStr .=     'AND pw_history_index = ? ';
-					$ret = $this->execStatement($queryStr, array($productId, $langId, $historyIndex -1));
-					if (!$ret) return false;
-				}
-			}
-		}
 		// 新規レコード追加
 		$queryStr = 'INSERT INTO product_with_category ';
 		$queryStr .=  '(';
-		$queryStr .=  'pw_product_id, ';
-		$queryStr .=  'pw_language_id, ';
-		$queryStr .=  'pw_history_index, ';
+		$queryStr .=  'pw_product_serial, ';
 		$queryStr .=  'pw_index, ';
 		$queryStr .=  'pw_category_id) ';
 		$queryStr .=  'VALUES ';
-		$queryStr .=  '(?, ?, ?, ?, ?)';
-		$ret =$this->execStatement($queryStr, array($productId, $langId, $historyIndex, $index, $categoryId));
+		$queryStr .=  '(?, ?, ?)';
+		$ret =$this->execStatement($queryStr, array($productSerial, $index, $categoryId));
 		return $ret;
 	}
 	/**
@@ -1087,7 +1039,7 @@ class productDb extends BaseDb
 		if (empty($categoryId)){
 			$queryStr = 'SELECT distinct(pt_serial) FROM product ';
 		} else {
-			$queryStr = 'SELECT distinct(pt_serial) FROM product RIGHT JOIN product_with_category ON pt_id = pw_product_id AND pt_language_id = pw_language_id AND pt_history_index = pw_history_index ';
+			$queryStr = 'SELECT distinct(pt_serial) FROM product RIGHT JOIN product_with_category ON pt_serial = pw_product_serial ';
 		}
 		$queryStr .=  'WHERE pt_language_id = ? '; $params[] = $lang;
 		$queryStr .=    'AND pt_deleted = false ';		// 削除されていない
@@ -1136,7 +1088,7 @@ class productDb extends BaseDb
 		if (empty($categoryId)){
 			$queryStr = 'SELECT distinct(pt_serial) FROM product ';
 		} else {
-			$queryStr = 'SELECT distinct(pt_serial) FROM product RIGHT JOIN product_with_category ON pt_id = pw_product_id AND pt_language_id = pw_language_id AND pt_history_index = pw_history_index ';
+			$queryStr = 'SELECT distinct(pt_serial) FROM product RIGHT JOIN product_with_category ON pt_serial = pw_product_serial ';
 		}
 		$queryStr .=  'WHERE pt_language_id = ? '; $params[] = $lang;
 		$queryStr .=    'AND pt_deleted = false ';		// 削除されていない
