@@ -101,8 +101,8 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 		// 呼び出し元からの設定値
 		$act = $request->trimValueOf('act');
 		if (empty($act)){		// 初期呼び出し時
-			$defSerial = $request->trimValueOf('serial');		// ページ定義のレコードシリアル番号
-			$configId = $request->trimValueOf('configid');
+			$defSerial = $request->trimValueOf('_defserial');		// ページ定義のレコードシリアル番号
+			$configId = $request->trimValueOf('_defconfig');
 
 			// 定義IDが設定されている場合は取得
 			if (!empty($configId)) $this->selType = $configId;
