@@ -80,11 +80,9 @@ class product_randomDb extends BaseDb
 			
 			// 商品カテゴリー
 			$queryStr  = 'SELECT * FROM product_with_category ';
-			$queryStr .=   'WHERE pw_product_id = ? ';
-			$queryStr .=     'AND pw_language_id = ? ';
-			$queryStr .=     'AND pw_history_index = ? ';// 履歴IDは共通
+			$queryStr .=   'WHERE pw_product_serial = ? ';
 			$queryStr .=  'ORDER BY pw_index ';
-			$this->selectRecords($queryStr, array($row['pt_id'], $row['pt_language_id'], $row['pt_history_index']), $row5);
+			$this->selectRecords($queryStr, array($row['pt_serial']), $row5);
 		}
 		return $ret;
 	}
