@@ -22,7 +22,7 @@ class admin_m_contentWidgetContainer extends BaseWidgetContainer
 	private $db;	// DB接続オブジェクト
 	private $serialNo;		// 選択中の項目のシリアル番号
 	private $serialArray = array();		// 表示されているコンテンツシリアル番号
-	private $_menuId = 'main_menu';				// メインメニューID
+	const MAIN_MENU_ID = 'mobile_menu';			// メニューID
 	const INC_INDEX = 1;		// メニュー項目表示順の増加分
 	const ADMIN_WIDGET_ID = 'admin_main';		// 管理ウィジェットのウィジェットID
 	const CONTENT_TYPE = 'mobile';			// コンテンツタイプ
@@ -95,12 +95,12 @@ class admin_m_contentWidgetContainer extends BaseWidgetContainer
 			$contentId = $request->trimValueOf('contentid');		// コンテンツID
 			
 			// このウィジェットがマップされているページサブIDを取得
-			$subPageId = $gPageManager->getPageSubIdByWidget($gEnvManager->getDefaultPageId(), $gEnvManager->getCurrentWidgetId());
+			$subPageId = $gPageManager->getPageSubIdByWidget($gEnvManager->getDefaultMobilePageId(), $gEnvManager->getCurrentWidgetId());
 			$sub = '';
 			if (!empty($subPageId)) $sub = 'sub=' . $subPageId . '&';
 			
 			// URLの作成
-			$url = M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END . '/index.php?' . $sub . 'contentid=' . $contentId;
+			$url = M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END . '/m/index.php?' . $sub . 'contentid=' . $contentId;
 
 			// コンテンツ名を取得
 			$menutItemName = '';
@@ -111,7 +111,7 @@ class admin_m_contentWidgetContainer extends BaseWidgetContainer
 			}
 			
 			// メニュー項目追加
-			$ret = $this->db->addMenuItem($this->_menuId, $langId, $menutItemName, $url, self::INC_INDEX, $userId);
+			$ret = $this->db->addMenuItem(self::MAIN_MENU_ID, $langId, $menutItemName, $url, self::INC_INDEX, $userId);
 			if ($ret){
 				$this->setGuidanceMsg('メインメニューに項目を追加しました');
 			} else {
@@ -231,7 +231,7 @@ class admin_m_contentWidgetContainer extends BaseWidgetContainer
 				}
 			} else {
 				// コンテンツを取得
-				$ret = $this->db->getContentByContentId($contentId, $langId, $row);
+				$ret = $this->db->getContentByContentId(self::CONTENT_TYPE, $contentId, $langId, $row);
 				if ($ret){
 					$this->serialNo = $row['cn_serial'];		// コンテンツシリアル番号
 					$reloadData = true;		// データの再読み込み
