@@ -55,6 +55,11 @@ class admin_reserve_mainWidgetContainer extends admin_reserve_mainBaseWidgetCont
 				$task = 'reserve';
 				$goWidget = true;		// サブウィジェットを実行するかどうか
 				break;
+			case 'user':		// ユーザ管理
+			case 'user_detail':		// ユーザ管理(詳細)
+				$task = 'user';
+				$goWidget = true;		// サブウィジェットを実行するかどうか
+				break;
 			case 'resource':		// リソース設定
 			case 'resource_detail':		// リソース設定(詳細)
 				$task = 'resource';
