@@ -540,5 +540,208 @@ class reserve_mainDb extends BaseDb
 		$queryStr .=  'ORDER BY li_family_name_kana, li_first_name_kana, li_id';
 		$this->selectLoop($queryStr, array(), $callback);
 	}
+	/**
+	 * 予約状況を取得
+	 *
+	 * @param int $id				リソースID
+	 * @param int $userId			ユーザID
+	 * @param timestamp $date		データを取得する先頭日付
+	 * @param int $status			取得するステータス(0=すべて、1=予約、2=キャンセル)
+	 * @param array	$rows			取得データ
+	 * @return						true=成功、false=失敗
+	 */
+	function getReserveStatus($id, $userId, $date, $status, &$rows)
+	{
+		$params = array();
+		$queryStr = 'SELECT * FROM reserve_status ';
+		$queryStr .=  'WHERE rs_deleted = false ';		// データが削除されていない
+		$queryStr .=    'AND rs_resource_id = ? '; $params[] = $id;		// リソースID
+		$queryStr .=    'AND rs_user_id = ? '; $params[] = $userId;		// ユーザID
+		if (!empty($date)){
+			$queryStr .=    'AND ? <= rs_start_dt ';
+			$params[] = $date;
+		}
+		if (!empty($status)){
+			$queryStr .=    'AND rs_status = ? ';
+			$params[] = $status;		// ステータス
+		}
+		$queryStr .=  'ORDER BY rs_start_dt ';
+		return $this->selectRecords($queryStr, $params, $rows);
+	}
+	/**
+	 * 予約状況を日付範囲で取得
+	 *
+	 * @param int $id				リソースID
+	 * @param timestamp $startDate		データを取得する先頭日付
+	 * @param timestamp $endDate		データを取得する終了日付(結果にこの日付のデータは含まれない)
+	 * @param int $status			取得するステータス(0=すべて、1=予約、2=キャンセル)
+	 * @param array	$rows			取得データ
+	 * @return						true=成功、false=失敗
+	 */
+	function getReserveStatusByDate($id, $startDate, $endDate, $status, &$rows)
+	{
+		$params = array();
+		$queryStr = 'SELECT * FROM reserve_status LEFT JOIN _login_user_info on rs_user_id = li_id ';
+		$queryStr .=  'WHERE rs_deleted = false AND li_deleted = false ';		// データが削除されていない
+		$queryStr .=    'AND rs_resource_id = ? '; $params[] = $id;		// リソースID
+		if (!empty($startDate)){
+			$queryStr .=    'AND ? <= rs_start_dt ';
+			$params[] = $startDate;
+		}
+		if (!empty($endDate)){
+			$queryStr .=    'AND rs_start_dt < ? ';
+			$params[] = $endDate;
+		}
+		if (!empty($status)){
+			$queryStr .=    'AND rs_status = ? ';
+			$params[] = $status;		// ステータス
+		}
+		$queryStr .=  'ORDER BY rs_start_dt, rs_serial ';
+		return $this->selectRecords($queryStr, $params, $rows);
+	}
+	/**
+	 * 指定時間の予約数を取得
+	 *
+	 * @param int $id				リソースID
+	 * @param int $userId			ユーザID(0のときはすべてのユーザ)
+	 * @param timestamp $date		データを取得する日付時間
+	 * @param int $status			取得するステータス(0=すべて、1=予約、2=キャンセル)
+	 * @param array	$rows			取得データ
+	 * @return						true=成功、false=失敗
+	 */
+	function getReserveStatusCountByDateTime($id, $userId, $date, $status)
+	{
+		$params = array();
+		$queryStr = 'SELECT * FROM reserve_status ';
+		$queryStr .=  'WHERE rs_deleted = false ';		// データが削除されていない
+		$queryStr .=    'AND rs_resource_id = ? '; $params[] = $id;		// リソースID
+		if (!empty($userId)){
+			$queryStr .=    'AND rs_user_id = ? ';
+			$params[] = $userId;
+		}
+		if (!empty($date)){
+			$queryStr .=    'AND rs_start_dt = ? ';
+			$params[] = $date;
+		}
+		if (!empty($status)){
+			$queryStr .=    'AND rs_status = ? ';
+			$params[] = $status;		// ステータス
+		}
+		return $this->selectRecordCount($queryStr, $params);
+	}
+	/**
+	 * 新規予約の追加
+	 *
+	 * @param int $id				リソースID
+	 * @param int $userId			ユーザID
+	 * @param timestamp $date		日付
+	 * @param int $status			ステータス(1=予約、2=キャンセル)
+	 * @param string $note			備考
+	 * @param int     $newSerial	新規レコードのシリアル番号
+	 * @return						true=成功、false=失敗
+	 */
+	function addReserveStatus($id, $userId, $date, $status, $note, &$newSerial)
+	{
+		global $gEnvManager;
+			
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$updateUserId = $gEnvManager->getCurrentUserId();	// データ更新ユーザ
+		
+		// トランザクション開始
+		$this->startTransaction();
+		
+		// 新規レコードを追加
+		$queryStr  = 'INSERT INTO reserve_status (';
+		$queryStr .=   'rs_resource_id, ';
+		$queryStr .=   'rs_user_id, ';
+		$queryStr .=   'rs_status, ';
+		$queryStr .=   'rs_start_dt, ';
+		$queryStr .=   'rs_note, ';
+		$queryStr .=   'rs_create_user_id, ';
+		$queryStr .=   'rs_create_dt ';
+		$queryStr .= ') VALUES (';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?) ';
+		$ret = $this->execStatement($queryStr, array($id, $userId, $status, $date, $note, $updateUserId, $now));
+		
+		// 新規のシリアル番号取得
+		$queryStr = 'select max(rs_serial) as ns from reserve_status ';
+		$ret = $this->selectRecord($queryStr, array(), $row);
+		if ($ret) $newSerial = $row['ns'];
+		
+		// トランザクション確定
+		$ret = $this->endTransaction();
+		return $ret;
+	}
+	/**
+	 * 予約の更新
+	 *
+	 * @param int $serial			シリアル番号
+	 * @param int $id				リソースID(確認用)
+	 * @param int $userId			ユーザID(確認用)
+	 * @param int $status			ステータス(1=予約、2=キャンセル)
+	 * @param string $note			備考
+	 * @return						true=成功、false=失敗
+	 */
+	function updateReserveStatus($serial, $id, $userId, $status, $note)
+	{
+		global $gEnvManager;
+			
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$updateUserId = $gEnvManager->getCurrentUserId();	// データ更新ユーザ
+		
+		// トランザクション開始
+		$this->startTransaction();
+		
+		$queryStr  = 'SELECT * FROM reserve_status ';
+		$queryStr .=   'WHERE rs_serial = ? ';
+		$queryStr .=   'AND rs_resource_id = ? ';
+		$queryStr .=   'AND rs_user_id = ? ';
+		$ret = $this->selectRecord($queryStr, array($serial, $id, $userId), $row);
+		if ($ret){		// 既に登録レコードがあるとき
+			if ($row['rs_deleted']){		// レコードが削除されていれば終了
+				// トランザクション確定
+				$ret = $this->endTransaction();
+				return false;
+			}
+		} else {		// 存在しない場合は終了
+			// トランザクション確定
+			$ret = $this->endTransaction();
+			return false;
+		}
+		
+		// データを更新
+		$queryStr  = 'UPDATE reserve_status ';
+		$queryStr .=   'SET rs_status = ?, ';
+		$queryStr .=     'rs_note = ?, ';
+		$queryStr .=     'rs_update_user_id = ?, ';
+		$queryStr .=     'rs_update_dt = ? ';
+		$queryStr .=   'WHERE rs_serial = ?';
+		$this->execStatement($queryStr, array($status, $note, $updateUserId, $now, $serial));
+		
+		// トランザクション確定
+		$ret = $this->endTransaction();
+		return $ret;
+	}
+	/**
+	 * 予約状況をシリアル番号で取得
+	 *
+	 * @param string	$serial				シリアル番号
+	 * @param array     $row				レコード
+	 * @return bool							取得 = true, 取得なし= false
+	 */
+	function getReserveStatusBySerial($serial, &$row)
+	{
+		$queryStr = 'SELECT * FROM reserve_status LEFT JOIN _login_user_info on rs_user_id = li_id ';
+		$queryStr .=  'WHERE rs_deleted = false ';		// データが削除されていない
+		$queryStr .=   'AND rs_serial = ? ';
+		$ret = $this->selectRecord($queryStr, array($serial), $row);
+		return $ret;
+	}
 }
 ?>
